package com.muyu.config;

import com.muyu.system.exception.BasicException;
import com.muyu.web.common.Result;
import jakarta.servlet.http.HttpServletRequest;
import lombok.extern.log4j.Log4j2;
import org.springframework.web.bind.MethodArgumentNotValidException;
import org.springframework.web.bind.annotation.ExceptionHandler;
import org.springframework.web.bind.annotation.RestControllerAdvice;

/**
 * 异常类
 * @author DongZeLiang
 * @version 1.0
 * @description 异常类
 * @date 2023/11/15
 */
@Log4j2
@RestControllerAdvice
public class ExceptionAdvice {

    /**
     * 运行时异常拦截
     * @param exception 运行时异常
     * @return 公共返回结果
     */
    @ExceptionHandler(value = RuntimeException.class)
    public Result<String> runtimeExceptionHandler(HttpServletRequest request, RuntimeException exception){
        log.error("请求发生异常：[{}] ----- [{}]",request.getRequestURI(), exception.getMessage(), exception);
        return Result.error(exception.getMessage());
    }
    /**
     * 运行时异常拦截
     * @param exception 运行时异常
     * @return 公共返回结果
     */
    @ExceptionHandler(value = BasicException.class)
    public Result<String> runtimeExceptionHandler(HttpServletRequest request, BasicException exception){
        log.error("请求发生异常：[{}] ----- [{}]",request.getRequestURI(), exception.getMessage(), exception);

        return Result.error(exception.getCode(), exception.getMessage());
    }
    /**
     * 运行时异常拦截
     * @param exception 运行时异常
     * @return 公共返回结果
     */
    @ExceptionHandler(value = MethodArgumentNotValidException.class)
    public Result<String> runtimeExceptionHandler(HttpServletRequest request, MethodArgumentNotValidException exception){
        log.error("请求发生异常：[{}] ----- [{}]",request.getRequestURI(), exception.getMessage(), exception);
        return Result.error(exception.getAllErrors().get(0).getDefaultMessage());
    }
}
