package com.muyu.system.handle;

import com.muyu.system.context.SystemUserContext;
import com.muyu.system.domain.LoginUserInfo;
import com.muyu.system.properties.ServerConfigProperties;

/**
 * @Description: 系统处理器
 * @author: MuYu
 * @date: 2024/9/11-上午10:23
 */
public class SystemHandler {

    /**
     * 获取登陆用户信息
     * @return 登陆用户信息
     */
    public static LoginUserInfo getUserInfo(){
        return SystemUserContext.get();
    }

    /**
     * 获取用户key
     * @return 用户Key
     */
    public static String getUserKey(){
        return getUserInfo().getUserKey();
    }


    /**
     * 登陆用户ID
     * @return 登录用户ID
     */
    public static Long getUserId(){
        return getUserInfo().getId();
    }

    /**
     * 获取服务器配置
     * @return 当前用户服务器配置
     */
    public static ServerConfigProperties getServerConfig(){
        return SystemUserContext.get().getServerConfig();
    }

    /**
     * 存储当前服务器配置
     */
    public static void setServerConfig(ServerConfigProperties serverConfig){
        SystemUserContext.get().setServerConfig(serverConfig);
    }

    /**
     * 获取负载地址
     * @return 负载地址
     */
    public static String getLoadReqUrl(){
        return getServerConfig().getLoadReqUrl();
    }

    /**
     * 获取租户ID
     * @return 租户ID
     */
    public static String getTenantId () {
        return getUserInfo().getTenantId();
    }
}
