package com.muyu.web.service.impl;

import com.alibaba.fastjson2.JSONArray;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.muyu.web.domain.PositionRouteInfo;
import com.muyu.web.domain.model.PositionModel;
import com.muyu.web.mapper.PositionRouteMapper;
import com.muyu.web.service.PositionRouteService;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * @author DongZl
 * @description: 路径轨迹业务实现层
 * @Date 2023-11-20 上午 09:34
 */
@Service
public class PositionRouteServiceImpl extends ServiceImpl<PositionRouteMapper, PositionRouteInfo> implements PositionRouteService {
    /**
     * 根据轨迹ID获取轨迹详情
     *
     * @param routeId 轨迹ID
     *
     * @return 轨迹ID
     */
    @Override
    public List<PositionModel> getPositionModelByRouteId (Long routeId) {
        PositionRouteInfo positionRouteInfo = this.getById(routeId);
        return JSONArray.parseArray(positionRouteInfo.getRouteData(), String.class)
                .stream()
                .map(PositionModel::strBuild)
                .toList();
    }

    /**
     * 根据轨迹 编号查询 估计详情
     *
     * @param positionCode 轨迹编号
     *
     * @return
     */
    @Override
    public List<PositionModel> getPositionModelByRouteName (String positionCode) {
        LambdaQueryWrapper<PositionRouteInfo> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.eq(PositionRouteInfo::getName, positionCode);
        PositionRouteInfo positionRouteInfo = getOne(queryWrapper);
        return JSONArray.parseArray(positionRouteInfo.getRouteData(), String.class)
                .stream()
                .map(PositionModel::strBuild)
                .toList();
    }
}
